==> lire_1.5.orig.tar.gz: lire-1.5/ftp/po/lire-ftp.pot.pl <==
# REFERENCE: ftp.cfg
__( q{Top Reports} );
# REFERENCE: ftp.cfg
__( q{Day Reports} );
# REFERENCE: ftp.cfg
__( q{Transfer Reports} );
# REFERENCE: schema:ftp
__( q{DLF Schema for FTP service} );
# REFERENCE: schema:ftp
__( q{This DLF file is adequate to represent most common
   informations about ftp transfers. It has the equivalent
   information of the xferlog format supported by many ftp servers.
  </para>
  <para>Each DLF record in the FTP schema reprensents one FTP
   transfer, this schema isn't adequate to represents complete FTP
   session.
  } );
# REFERENCE: schema:ftp
__( q{Timestamp} );
# REFERENCE: schema:ftp
__( q{The time at which the transfer started.} );
# REFERENCE: schema:ftp
__( q{Transfer's Time} );
# REFERENCE: schema:ftp
__( q{The time taken by the transfer.} );
# REFERENCE: schema:ftp
__( q{Client Host} );
# REFERENCE: schema:ftp
__( q{The hostname of the client that initiated the transfer.} );
# REFERENCE: schema:ftp
__( q{Size} );
# REFERENCE: schema:ftp
__( q{The number bytes transferred.} );
# REFERENCE: schema:ftp
__( q{File} );
# REFERENCE: schema:ftp
__( q{The filename that was transferred.} );
# REFERENCE: schema:ftp
__( q{Transfer's Type} );
# REFERENCE: schema:ftp
__( q{The method used for the transfer. This will
   <literal>ascii</literal> when ASCII conversion is used during the
    transfer and <literal>binary</literal> otherwise.
   } );
# REFERENCE: schema:ftp
__( q{Special} );
# REFERENCE: schema:ftp
__( q{A code used to represent special action accomplished by the
    server during the transfer. Valid codes besides the default are
    <literal>compress</literal>, <literal>uncompress</literal> and
    <literal>tar</literal>.
   } );
# REFERENCE: schema:ftp
__( q{Direction} );
# REFERENCE: schema:ftp
__( q{This should be <literal>upload</literal> for incoming transfer
    and <literal>dowload</literal> for outgoing transfer.
   } );
# REFERENCE: schema:ftp
__( q{Access Mode} );
# REFERENCE: schema:ftp
__( q{The type of authentication used. Valid values are
    <literal>anonymous</literal> when the use used anonymous login;
    <literal>guest</literal> for guest login and
    <literal>authenticated</literal> for when the user was
    authenticated through valid credentials.
   } );
# REFERENCE: schema:ftp
__( q{User} );
# REFERENCE: schema:ftp
__( q{The name of the authenticated user. In the case of guest or
    anonymous logins, this should be the email address or other
    identifier given by the user on logon.
   } );
# REFERENCE: schema:ftp
__( q{Service} );
# REFERENCE: schema:ftp
__( q{That's the name through which the service was invoked. This
    will usually be FTP.} );
# REFERENCE: schema:ftp
__( q{Auth Method} );
# REFERENCE: schema:ftp
__( q{Additional authentication that was done on the connection.
    The only defined value besides the default is
    <literal>ident</literal> for the case when the connection was
    authenticated through RFC1931 authentication.
   } );
# REFERENCE: schema:ftp
__( q{Authenticated User} );
# REFERENCE: schema:ftp
__( q{The user identification related to the
    <structfield>auth_method</structfield> mode of authentication.
   } );
# REFERENCE: schema:ftp
__( q{Completion Status} );
# REFERENCE: schema:ftp
__( q{This will be <literal>complete</literal> when the transfer
    completed successfully and <literal>incomplete</literal> when the
    transfer was aborted before it completes.
   } );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{Bytes by Direction by User with count by Period FTP Report} );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{This report shows the bytes transferred by direction (in or
   out) by user with the number of transfers by period.
  } );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{This parameter controls the time period which is used to
     aggregate the records.
    } );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{This parameter controls the number of users to
     display during each period.
    } );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{Total Bytes Transferred by Direction by User by $period
   Period, Top $users_to_show Users} );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{Period} );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{Bytes} );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{% Total} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{Bytes by Period by User FTP Report} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{This report shows for each user, the amount of bytes they
   transferred by period.
  } );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{This parameter controls the time period which is used to
     aggregate the records for each users.
    } );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{This parameter controls the number of users to
     display in the report.
    } );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{Total Bytes Transferred by $period Period by User, Top
   $users_to_show users} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{Period} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{Bytes} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{% Total} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{% User} );
# REFERENCE: report:ftp:bytes-by-period
__( q{Bytes by Period FTP Report} );
# REFERENCE: report:ftp:bytes-by-period
__( q{This report calculates the sum of all transfers by a
   user-confirable time period.
  } );
# REFERENCE: report:ftp:bytes-by-period
__( q{This parameter controls the time period which is use to
     aggregate the records.
    } );
# REFERENCE: report:ftp:bytes-by-period
__( q{Total Transferred Bytes by $period Period} );
# REFERENCE: report:ftp:bytes-by-period
__( q{Period} );
# REFERENCE: report:ftp:bytes-by-period
__( q{Bytes} );
# REFERENCE: report:ftp:bytes-by-period
__( q{% Total} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{Bytes by User by Period FTP Report} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{This report shows the bytes transferred by user by period.
  } );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{This parameter controls the time period which is used to
     aggregate the records.
    } );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{This parameter controls the number of users to
     display during each users.
    } );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{Total Bytes Transferred by User by $period Period, Top
   $users_to_show users} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{Period} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{Bytes} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{% Total} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{% Period} );
# REFERENCE: report:ftp:top-files-in
__( q{Top Uploaded Files FTP Report} );
# REFERENCE: report:ftp:top-files-in
__( q{This report lists the most uploaded files.} );
# REFERENCE: report:ftp:top-files-in
__( q{This parameter controls the number of files to
     display in the report.
    } );
# REFERENCE: report:ftp:top-files-in
__( q{Number of Uploads by File, Top $files_to_show} );
# REFERENCE: report:ftp:top-files-in
__( q{Uploads} );
# REFERENCE: report:ftp:top-files-in
__( q{% Total} );
# REFERENCE: report:ftp:top-files-out
__( q{Top Downloaded Files FTP Report} );
# REFERENCE: report:ftp:top-files-out
__( q{This report lists the most downloaded files.} );
# REFERENCE: report:ftp:top-files-out
__( q{This parameter controls the number of files to
     display in the report.
    } );
# REFERENCE: report:ftp:top-files-out
__( q{Number of Downloads by File, Top $files_to_show} );
# REFERENCE: report:ftp:top-files-out
__( q{Downloads} );
# REFERENCE: report:ftp:top-files-out
__( q{% Total} );
# REFERENCE: report:ftp:top-files
__( q{Top Files FTP Report} );
# REFERENCE: report:ftp:top-files
__( q{This report lists the most requested files.} );
# REFERENCE: report:ftp:top-files
__( q{This parameter controls the number of files to
     display in the report.
    } );
# REFERENCE: report:ftp:top-files
__( q{Number of Transfers by File, Top $files_to_show} );
# REFERENCE: report:ftp:top-files
__( q{Transfers} );
# REFERENCE: report:ftp:top-files
__( q{% Total} );
# REFERENCE: report:ftp:top-remote-host
__( q{Top Remote Host FTP Report} );
# REFERENCE: report:ftp:top-remote-host
__( q{This report lists the remote hosts with the most requests.} );
# REFERENCE: report:ftp:top-remote-host
__( q{This parameter controls the number of remote hosts to
     display in the report.
    } );
# REFERENCE: report:ftp:top-remote-host
__( q{Number of Transfers by Remote Hosts, Top $hosts_to_show} );
# REFERENCE: report:ftp:top-remote-host
__( q{Transfers} );
# REFERENCE: report:ftp:top-remote-host
__( q{% Total} );
# REFERENCE: report:ftp:top-users-bytes
__( q{Top by User (Bytes Transferred) FTP Report} );
# REFERENCE: report:ftp:top-users-bytes
__( q{This report lists the users with the highest amount of bytes
   transferred.
  } );
# REFERENCE: report:ftp:top-users-bytes
__( q{This parameter controls the number of users to
     display in the report.
    } );
# REFERENCE: report:ftp:top-users-bytes
__( q{Bytes Transferred by Users, Top $users_to_show} );
# REFERENCE: report:ftp:top-users-bytes
__( q{Bytes} );
# REFERENCE: report:ftp:top-users-bytes
__( q{% Total} );
# REFERENCE: report:ftp:top-users
__( q{Top Users FTP Report} );
# REFERENCE: report:ftp:top-users
__( q{This report lists the most active users.} );
# REFERENCE: report:ftp:top-users
__( q{This parameter controls the number of users to
     display in the report.
    } );
# REFERENCE: report:ftp:top-users
__( q{Number of Transfers by Users, Top $users_to_show} );
# REFERENCE: report:ftp:top-users
__( q{Transfers} );
# REFERENCE: report:ftp:top-users
__( q{% Total} );
# REFERENCE: report:ftp:tracked-files
__( q{Tracked Files FTP Report} );
# REFERENCE: report:ftp:tracked-files
__( q{This report shows each download of tracked files.} );
# REFERENCE: report:ftp:tracked-files
__( q{This parameter controls which files will be included
     in the report.
    } );
# REFERENCE: report:ftp:tracked-files
__( q{Downloads By Tracked File ($tracked_file_re)} );
# REFERENCE: report:ftp:tracked-files
__( q{Downloads} );
# REFERENCE: report:ftp:tracked-users
__( q{Tracked Users FTP Report} );
# REFERENCE: report:ftp:tracked-users
__( q{This report shows each download for tracked users.} );
# REFERENCE: report:ftp:tracked-users
__( q{This parameter controls which user will be included
     in the report.
    } );
# REFERENCE: report:ftp:tracked-users
__( q{Downloads By Tracked User ($tracked_user_re)} );
# REFERENCE: report:ftp:tracked-users
__( q{Downloads} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{Number of Transfers by Direction FTP Report} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{This report lists the number of transfers by direction.} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{Number of Transfers by Direction} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{Transfers} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{% Total} );
# REFERENCE: report:ftp:transfers-by-file
__( q{Each Transfer by Filename Report} );
# REFERENCE: report:ftp:transfers-by-file
__( q{This report lists the transfers for each file.} );
# REFERENCE: report:ftp:transfers-by-file
__( q{Transfers by Filename} );
# REFERENCE: report:ftp:transfers-by-type
__( q{Number of Transfers by Transfer Type FTP Report} );
# REFERENCE: report:ftp:transfers-by-type
__( q{This report lists the number of transfers by transfer type.} );
# REFERENCE: report:ftp:transfers-by-type
__( q{Number of Transfers by Transfer Type} );
# REFERENCE: report:ftp:transfers-by-type
__( q{Transfers} );
# REFERENCE: report:ftp:transfers-by-type
__( q{% Total} );

==> lire_2.1.1.orig.tar.gz: lire-2.1.1/ftp/po/lire-ftp.pot.pl <==
# REFERENCE: ftp_default.xml
__( q{Top Reports} );
# REFERENCE: ftp_default.xml
__( q{Day Reports} );
# REFERENCE: ftp_default.xml
__( q{Transfer Reports} );
# REFERENCE: schema:ftp
__( q{DLF Schema for FTP service} );
# REFERENCE: schema:ftp
__( q{This DLF file is adequate to represent most common informations about ftp transfers. It has the equivalent information of the xferlog format supported by many ftp servers. </para> <para>Each DLF record in the FTP schema reprensents one FTP transfer, this schema isn't adequate to represents complete FTP session. } );
# REFERENCE: schema:ftp
__( q{Timestamp} );
# REFERENCE: schema:ftp
__( q{The time at which the transfer started.} );
# REFERENCE: schema:ftp
__( q{Transfer's Time} );
# REFERENCE: schema:ftp
__( q{The time taken by the transfer.} );
# REFERENCE: schema:ftp
__( q{Client Host} );
# REFERENCE: schema:ftp
__( q{The hostname of the client that initiated the transfer.} );
# REFERENCE: schema:ftp
__( q{Size} );
# REFERENCE: schema:ftp
__( q{The number bytes transferred.} );
# REFERENCE: schema:ftp
__( q{File} );
# REFERENCE: schema:ftp
__( q{The filename that was transferred.} );
# REFERENCE: schema:ftp
__( q{Transfer's Type} );
# REFERENCE: schema:ftp
__( q{The method used for the transfer. This will <literal>ascii</literal> when ASCII conversion is used during the transfer and <literal>binary</literal> otherwise. } );
# REFERENCE: schema:ftp
__( q{Special} );
# REFERENCE: schema:ftp
__( q{A code used to represent special action accomplished by the server during the transfer. Valid codes besides the default are <literal>compress</literal>, <literal>uncompress</literal> and <literal>tar</literal>. } );
# REFERENCE: schema:ftp
__( q{Direction} );
# REFERENCE: schema:ftp
__( q{This should be <literal>upload</literal> for incoming transfer and <literal>dowload</literal> for outgoing transfer. } );
# REFERENCE: schema:ftp
__( q{Access Mode} );
# REFERENCE: schema:ftp
__( q{The type of authentication used. Valid values are <literal>anonymous</literal> when the use used anonymous login; <literal>guest</literal> for guest login and <literal>authenticated</literal> for when the user was authenticated through valid credentials. } );
# REFERENCE: schema:ftp
__( q{User} );
# REFERENCE: schema:ftp
__( q{The name of the authenticated user. In the case of guest or anonymous logins, this should be the email address or other identifier given by the user on logon. } );
# REFERENCE: schema:ftp
__( q{Service} );
# REFERENCE: schema:ftp
__( q{That's the name through which the service was invoked. This will usually be FTP.} );
# REFERENCE: schema:ftp
__( q{Auth Method} );
# REFERENCE: schema:ftp
__( q{Additional authentication that was done on the connection. The only defined value besides the default is <literal>ident</literal> for the case when the connection was authenticated through RFC1931 authentication. } );
# REFERENCE: schema:ftp
__( q{Authenticated User} );
# REFERENCE: schema:ftp
__( q{The user identification related to the <structfield>auth_method</structfield> mode of authentication. } );
# REFERENCE: schema:ftp
__( q{Completion Status} );
# REFERENCE: schema:ftp
__( q{This will be <literal>complete</literal> when the transfer completed successfully and <literal>incomplete</literal> when the transfer was aborted before it completes. } );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{Bytes by Direction by User with count by Period FTP Report} );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{This report shows the bytes transferred by direction (in or out) by user with the number of transfers by period. } );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{This parameter controls the time period which is used to aggregate the records. } );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{This parameter controls the number of users to display during each period. } );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{Total Bytes Transferred by Direction by User by $period Period, Top $users_to_show Users} );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{Period} );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{Bytes} );
# REFERENCE: report:ftp:bytes-by-dir-by-user-by-period
__( q{% Total} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{Bytes by Period by User FTP Report} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{This report shows for each user, the amount of bytes they transferred by period. } );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{This parameter controls the time period which is used to aggregate the records for each users. } );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{This parameter controls the number of users to display in the report. } );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{Total Bytes Transferred by $period Period by User, Top $users_to_show users} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{Period} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{Bytes} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{% Total} );
# REFERENCE: report:ftp:bytes-by-period-by-user
__( q{% User} );
# REFERENCE: report:ftp:bytes-by-period
__( q{Bytes by Period FTP Report} );
# REFERENCE: report:ftp:bytes-by-period
__( q{This report calculates the sum of all transfers by a user-confirable time period. } );
# REFERENCE: report:ftp:bytes-by-period
__( q{This parameter controls the time period which is use to aggregate the records. } );
# REFERENCE: report:ftp:bytes-by-period
__( q{Total Transferred Bytes by $period Period} );
# REFERENCE: report:ftp:bytes-by-period
__( q{Period} );
# REFERENCE: report:ftp:bytes-by-period
__( q{Bytes} );
# REFERENCE: report:ftp:bytes-by-period
__( q{% Total} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{Bytes by User by Period FTP Report} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{This report shows the bytes transferred by user by period. } );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{This parameter controls the time period which is used to aggregate the records. } );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{This parameter controls the number of users to display during each users. } );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{Total Bytes Transferred by User by $period Period, Top $users_to_show users} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{Period} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{Bytes} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{% Total} );
# REFERENCE: report:ftp:bytes-by-user-by-period
__( q{% Period} );
# REFERENCE: report:ftp:top-files-in
__( q{Top Uploaded Files FTP Report} );
# REFERENCE: report:ftp:top-files-in
__( q{This report lists the most uploaded files.} );
# REFERENCE: report:ftp:top-files-in
__( q{This parameter controls the number of files to display in the report. } );
# REFERENCE: report:ftp:top-files-in
__( q{Number of Uploads by File, Top $files_to_show} );
# REFERENCE: report:ftp:top-files-in
__( q{Uploads} );
# REFERENCE: report:ftp:top-files-in
__( q{% Total} );
# REFERENCE: report:ftp:top-files-out
__( q{Top Downloaded Files FTP Report} );
# REFERENCE: report:ftp:top-files-out
__( q{This report lists the most downloaded files.} );
# REFERENCE: report:ftp:top-files-out
__( q{This parameter controls the number of files to display in the report. } );
# REFERENCE: report:ftp:top-files-out
__( q{Number of Downloads by File, Top $files_to_show} );
# REFERENCE: report:ftp:top-files-out
__( q{Downloads} );
# REFERENCE: report:ftp:top-files-out
__( q{% Total} );
# REFERENCE: report:ftp:top-files
__( q{Top Files FTP Report} );
# REFERENCE: report:ftp:top-files
__( q{This report lists the most requested files.} );
# REFERENCE: report:ftp:top-files
__( q{This parameter controls the number of files to display in the report. } );
# REFERENCE: report:ftp:top-files
__( q{Number of Transfers by File, Top $files_to_show} );
# REFERENCE: report:ftp:top-files
__( q{Transfers} );
# REFERENCE: report:ftp:top-files
__( q{% Total} );
# REFERENCE: report:ftp:top-remote-host
__( q{Top Remote Host FTP Report} );
# REFERENCE: report:ftp:top-remote-host
__( q{This report lists the remote hosts with the most requests.} );
# REFERENCE: report:ftp:top-remote-host
__( q{This parameter controls the number of remote hosts to display in the report. } );
# REFERENCE: report:ftp:top-remote-host
__( q{Number of Transfers by Remote Hosts, Top $hosts_to_show} );
# REFERENCE: report:ftp:top-remote-host
__( q{Transfers} );
# REFERENCE: report:ftp:top-remote-host
__( q{% Total} );
# REFERENCE: report:ftp:top-users-bytes
__( q{Top by User (Bytes Transferred) FTP Report} );
# REFERENCE: report:ftp:top-users-bytes
__( q{This report lists the users with the highest amount of bytes transferred. } );
# REFERENCE: report:ftp:top-users-bytes
__( q{This parameter controls the number of users to display in the report. } );
# REFERENCE: report:ftp:top-users-bytes
__( q{Bytes Transferred by Users, Top $users_to_show} );
# REFERENCE: report:ftp:top-users-bytes
__( q{Bytes} );
# REFERENCE: report:ftp:top-users-bytes
__( q{% Total} );
# REFERENCE: report:ftp:top-users
__( q{Top Users FTP Report} );
# REFERENCE: report:ftp:top-users
__( q{This report lists the most active users.} );
# REFERENCE: report:ftp:top-users
__( q{This parameter controls the number of users to display in the report. } );
# REFERENCE: report:ftp:top-users
__( q{Number of Transfers by Users, Top $users_to_show} );
# REFERENCE: report:ftp:top-users
__( q{Transfers} );
# REFERENCE: report:ftp:top-users
__( q{% Total} );
# REFERENCE: report:ftp:tracked-files
__( q{Tracked Files FTP Report} );
# REFERENCE: report:ftp:tracked-files
__( q{This report shows each download of tracked files.} );
# REFERENCE: report:ftp:tracked-files
__( q{This parameter controls which files will be included in the report. } );
# REFERENCE: report:ftp:tracked-files
__( q{Downloads By Tracked File ($tracked_file_re)} );
# REFERENCE: report:ftp:tracked-files
__( q{Downloads} );
# REFERENCE: report:ftp:tracked-users
__( q{Tracked Users FTP Report} );
# REFERENCE: report:ftp:tracked-users
__( q{This report shows each download for tracked users.} );
# REFERENCE: report:ftp:tracked-users
__( q{This parameter controls which user will be included in the report. } );
# REFERENCE: report:ftp:tracked-users
__( q{Downloads By Tracked User ($tracked_user_re)} );
# REFERENCE: report:ftp:tracked-users
__( q{Downloads} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{Number of Transfers by Direction FTP Report} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{This report lists the number of transfers by direction.} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{Number of Transfers by Direction} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{Transfers} );
# REFERENCE: report:ftp:transfers-by-direction
__( q{% Total} );
# REFERENCE: report:ftp:transfers-by-file
__( q{Each Transfer by Filename Report} );
# REFERENCE: report:ftp:transfers-by-file
__( q{This report lists the transfers for each file.} );
# REFERENCE: report:ftp:transfers-by-file
__( q{Transfers by Filename} );
# REFERENCE: report:ftp:transfers-by-type
__( q{Number of Transfers by Transfer Type FTP Report} );
# REFERENCE: report:ftp:transfers-by-type
__( q{This report lists the number of transfers by transfer type.} );
# REFERENCE: report:ftp:transfers-by-type
__( q{Number of Transfers by Transfer Type} );
# REFERENCE: report:ftp:transfers-by-type
__( q{Transfers} );
# REFERENCE: report:ftp:transfers-by-type
__( q{% Total} );
